#
# spec file for package smtube
#
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
# Copyright (c) 2015 Packman team: http://packman.links2linux.org/
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/


%define majver 15.5

Name:           smtube
Version:        15.5.17
Release:        1.1
Summary:        Small Youtube Browser
License:        GPL-2.0
Group:          Productivity/Multimedia/Video/Players
URL:            http://smtube.sourceforge.net/
Source0:        http://downloads.sourceforge.net/smtube/SMTube/%{majver}/%{name}-%{version}.tar.bz2
# Fix 'File is compiled without RPM_OPT_FLAGS'
Patch0:         %{name}-src_%{name}.pro.patch
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
%endif
BuildRequires:  dos2unix
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(QtWebKit)
Recommends:     MPlayer
Recommends:     smplayer
Recommends:     vlc
Recommends:     mpv

%description
SMTube allows to search, play and download Youtube videos.
Videos are played back with a media player (by default SMPlayer)
instead of a flash player, this allows better performance,
particularly with HD content. SMTube also allows to download the videos,
with the quality you choose. Several videos can be downloaded at a time.

SMTube is included in SMPlayer's menus, to run it just select Youtube browser
in the Options menu in the SMPlayer main window, or just press F11.

%lang_package

%prep
%setup -q
%patch0

# SED-FIX-OPENSUSE -- Fix paths
sed -i -e 's|/usr/local|/usr|;
           s|/share/doc/|/share/doc/packages/|' Makefile

# SED-FIX-OPENSUSE -- Fix zero-length docs
cp debian-rvm/changelog-orig Changelog

# Some docs have the DOS line ends
dos2unix Changelog *.txt

%build
make %{?_smp_mflags} \
     PREFIX="%{_prefix}" \
     DATA_PATH="%{_datadir}/%{name}" \
     DOC_PATH="%{_docdir}/%{name}" \
     KDE_PREFIX="%{_prefix}" \
     OPTFLAGS="%{optflags}"

%install
%make_install
%find_lang %name --with-qt

%if 0%{?suse_version}
    %suse_update_desktop_file %{name}
    %fdupes -s %{buildroot}%{_prefix}
%endif

%files
%defattr(-,root,root,-)
%doc Changelog *.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%files lang -f %{name}.lang
%defattr(-,root,root,-)
%{_datadir}/%{name}

%changelog
* Tue May 26 2015 nemysis@gmx.ch
- Update to 15.5.17, announce message:
  * Fixed some bugs.
- Change URL
- Change Source0 Web URL
- Fix zero-length docs
* Mon May 11 2015 dap.darkness@gmail.com
- update to 15.5.10:
  * no upstream changelog.
- Updated smtube-src_smtube.pro.patch.
* Tue Jan 20 2015 dap.darkness@gmail.com
- update to 15.1.0:
  * Fix for VEVO videos.
* Wed Dec 31 2014 dap.darkness@gmail.com
- update to 14.12.0:
  * New options to set a proxy.
* Thu Nov 20 2014 nemysis@gmx.ch
- Remove sed for smtube_nqo.ts
- Use %%{_datadir}/icons/hicolor/*/apps/%%{name}.png
  instead of %%{_datadir}/icons/hicolor/
* Tue Nov 18 2014 nemysis@gmx.ch
- Change URL
- Use for Release 0
- Change Source0 Web URL
- Use smtube-src_smtube.pro.patch instead of
  smtube-optflags.patch and add description
- Use check for openSUSE %%if 0%%{?suse_version}
- Add BuildRequires for dos2unix and fdupes
- Remove BuildRequires for make
- Change description
- Fix paths
- Remove not working Translation to not get
  error: Installed (but unpackaged) file(s) found:
  smtube_nqo.qm
- Simplify installation handling, use normal build
- Use default make %%{?_smp_mflags} and %%make_install
- Use simple %%find_lang %%name --with-qt
* Thu Aug 28 2014 dap.darkness@gmail.com
- update to 14.8.0:
  * Fix playback (for players other than smplayer).
* Sat Jul 12 2014 dap.darkness@gmail.com
- update to 14.7.0:
  * Fix the option Record audio.
  * New translations: Albanian, Slovak and English UK.
- Mplayer, smplayer or vlc can be used.
- smtube-optflags.patch was updated.
* Mon Apr  7 2014 dap.darkness@gmail.com
- update to 2.1:
  * Add the Italian, French, Czech, Malay, Swedish,
    Turkish, Finnish, Georgian, Portuguese (Brazil),
    Ukrainian, Norwegian, Hebrew, Croatian, Bulgarian,
    Vietnamese and Indonesian translation.
  * When saving DASH 1080, be sure the video and audio files
    have the same name.
  * Increase speed when downloading DASH streams.
  * If there's no 1080p video in the normal format, try
    to download the 1080p video in the DASH format. That
    actually downloads two files, a mp4 with the video only
    and a m4a with the audio.
  * Add an option to record audio.
  * Use the user's country for default region.
  * Add two actions to increase or reduce the font size
    (shortcuts Ctrl+Plus and Ctrl+Minus).
  * Add mpv to the list of players.
  * Add an option to add URL to the SMPlayer playlist.
  * Keys work now in the video list.
  * Ask the user to update the youtube code
    when an unknown signature is found.
  * The quality for recording has now more options and allows
    to save the video in webm format as well.
  * Possibility to select the playback quality
    (for players other than smplayer).
  * Add support for the new signatures of Youtube.
  * Add options in the configuration dialog to select the
    preferred region and period of time for the standard feeds.
  * Save the recording list.
  * Add a button to open the recording dialog.
- Updated smtube-optflags.patch.
- Removed clean section.
- Let lang subpackage become recommended.
* Fri Oct 19 2012 pascal.bleser@opensuse.org
- update to 1.2:
  * Update for Youtube changes
  * Usability improvements
* Sun Apr 15 2012 pascal.bleser@opensuse.org
- initial version (1.1)
